.. -*- mode: rst -*-

Gallery
=======

Feature Analysis
----------------

.. image:: images/gallery/radviz.png
    :width: 200px
    :height: 100px
    :alt: Features Analysis RadViz Visualizer
    :target: api/features/radviz.html#radviz-visualizer

.. image:: images/gallery/rank1d_shapiro.png
    :width: 200px
    :height: 100px
    :alt: Features Analysis Shapiro Rank1D
    :target: api/features/rankd.html#rank-1d

.. image:: images/gallery/rank2d_covariance.png
    :width: 200px
    :height: 100px
    :alt: Features Analysis Covariance Rank2D
    :target: api/features/rankd.html#rank-2d

.. image:: images/gallery/parallel_coordinates.png
    :width: 200px
    :height: 100px
    :alt: Parallel Coordinates for 5 features
    :target: api/features/pcoords.html#parallel-coordinates

.. image:: images/gallery/pca_projection_3d.png
    :width: 200px
    :height: 100px
    :alt: Principal Component Plot 3D
    :target: api/features/pca.html#pca-projection

.. image:: images/gallery/concrete_tsne_manifold.png
    :width: 200px
    :height: 100px
    :alt: t-SNE Manifold Visualization
    :target: api/features/manifold.html#manifold-visualization

.. image:: images/gallery/occupancy_tsne_manifold.png
    :width: 200px
    :height: 100px
    :alt: t-SNE Manifold Visualization Discrete Target
    :target: api/features/manifold.html#discrete-target

.. image:: images/gallery/concrete_isomap_manifold.png
    :width: 200px
    :height: 100px
    :alt: Isomap Manifold Visualization
    :target: api/features/manifold.html#continuous-target

.. image:: images/gallery/scatter.png
    :width: 200px
    :height: 100px
    :alt: Scatter Visualization
    :target: api/contrib/scatter.html#scatter-visualization

.. image:: images/gallery/jointplot.png
    :width: 200px
    :height: 100px
    :alt: Joint Point Visualization
    :target: api/features/jointplot.html#joint-plot-visualization


Regression Visualizers
----------------------

.. image:: images/gallery/residuals.png
    :width: 200px
    :height: 100px
    :alt: Residuals for Ridge Model
    :target: api/regressor/residuals.html#residuals-plot

.. image:: images/gallery/prediction_error.png
    :width: 200px
    :height: 100px
    :alt: Prediction Error for Lasso
    :target: api/regressor/peplot.html#residuals-plot

.. image:: images/gallery/alpha_selection.png
    :width: 200px
    :height: 100px
    :alt: Alpha Selection for Lasso
    :target: api/regressor/alphas.html#alpha-selection


Classification Visualizers
--------------------------

.. image:: images/gallery/classification_report.png
    :width: 200px
    :height: 100px
    :alt: GaussianNB Classification Report
    :target: api/classifier/classification_report.html#classification-report

.. image:: images/gallery/confusion_matrix_digits.png
    :width: 200px
    :height: 100px
    :alt: Logistic Regression Confusion Matrix with Numeric Labels
    :target: api/classifier/confusion_matrix.html#confusion-matrix

.. image:: images/gallery/confusion_matrix_iris.png
    :width: 200px
    :height: 100px
    :alt: Logistic Regression Confusion Matrix with Class Name Labels
    :target: api/classifier/confusion_matrix.html#plotting-with-class-names

.. image:: images/gallery/rocauc_binary.png
    :width: 200px
    :height: 100px
    :alt: Binary ROC Curves
    :target: api/classifier/rocauc.html#rocauc

.. image:: images/gallery/rocauc_multiclass.png
    :width: 200px
    :height: 100px
    :alt: Multiclass ROC Curves
    :target: api/classifier/rocauc.html#multi-class-rocauc-curves

.. image:: images/gallery/precision_recall_binary.png
    :width: 200px
    :height: 100px
    :alt: Precision-Recall Curves
    :target: api/classifier/prcurve.html

.. image:: images/gallery/precision_recall_multiclass.png
    :width: 200px
    :height: 100px
    :alt: Multiclass Precision-Recall Curves
    :target: api/classifier/prcurve.html#multi-label-classification

.. image:: images/gallery/class_prediction_error.png
    :width: 200px
    :height: 100px
    :alt: Class Prediction Error of Classifier
    :target: api/classifier/class_prediction_error.html#class-prediction-error

.. image:: images/gallery/discrimination_threshold.png
    :width: 200px
    :height: 100px
    :alt: Discrimination Threshold Plot
    :target: api/classifier/threshold.html#discrimination-threshold

Clustering Visualizers
----------------------

.. image:: images/gallery/elbow.png
    :width: 200px
    :height: 100px
    :alt: Distortion Score Elbow for Mini Batch Means Clustering
    :target: api/cluster/elbow.html#elbow-method

.. image:: images/gallery/silhouette.png
    :width: 200px
    :height: 100px
    :alt: Silhoutte Plot of Mini Batch Kmeans Clustering
    :target: api/cluster/silhouette.html#silhouette-visualizer

.. image:: images/gallery/icdm.png
    :width: 200px
    :height: 100px
    :alt: Intercluster Distance Maps
    :target: api/cluster/icdm.html#intercluster-distance-maps

Model Selection Visualizers
---------------------------

.. image:: images/gallery/validation_curve.png
    :width: 200px
    :height: 100px
    :alt: Validation Curve Hyperparameter Tuning
    :target: api/model_selection/validation_curve.html#validation-curve

.. image:: images/gallery/learning_curve.png
    :width: 200px
    :height: 100px
    :alt: Learning Curves for Data Sufficiency
    :target: api/model_selection/learning_curve.html

.. image:: images/gallery/cv_scores.png
    :width: 200px
    :height: 100px
    :alt: Cross Validation Scores
    :target: api/model_selection/cross_validation.html

.. image:: images/gallery/decision_boundaries.png
    :width: 200px
    :height: 100px
    :alt: Nearest Neighbor Decision Boundary Prototype
    :target: api/contrib/boundaries.html#decisionboundaries-vizualizer

.. image:: images/gallery/feature_importances.png
    :width: 200px
    :height: 100px
    :alt: Feature Importance using Ensemble Classifier
    :target: api/model_selection/importances.html#feature-importances

.. image:: images/gallery/rfecv_sklearn_example.png
    :width: 200px
    :height: 100px
    :alt: Recursive Feature Elimination with Ensemble Classifier
    :target: api/model_selection/rfecv.html#recursive-feature-elimination

Text Modeling Visualizers
---------------------------

.. image:: images/gallery/freqdist.png
    :width: 200px
    :height: 100px
    :alt: Token Frequency Distribution
    :target: api/text/freqdist.html#token-frequency-distribution

.. image:: images/gallery/corpus_tsne.png
    :width: 200px
    :height: 100px
    :alt: TSNE Projection of Documents
    :target: api/text/tsne.html#t-sne-corpus-visualization

.. image:: images/gallery/dispersion.png
    :width: 200px
    :height: 100px
    :alt: Dispersion of Words in a Corpus
    :target: api/text/dispersion.html#dispersion-plot

.. image:: images/gallery/word_correlation.png
    :width: 200px
    :height: 100px
    :alt: Correlation between Words in a Corpus
    :target: api/text/correlation.html#correlation

.. image:: images/gallery/postag.png
    :width: 200px
    :height: 100px
    :alt: Parts-of-Speech in a Tagged Corpus
    :target: api/text/postag.html#postag-visualization


Target Visualizers
------------------

.. image:: images/gallery/balanced_binning_reference.png
    :width: 200px
    :height: 100px
    :alt: Balanced Binning Reference
    :target: api/target/binning.html#balanced-binning-reference

.. image:: images/gallery/class_balance.png
    :width: 200px
    :height: 100px
    :alt: Class Balance
    :target: api/target/class_balance.html#class-balance

.. image:: images/gallery/feature_correlation.png
    :width: 200px
    :height: 100px
    :alt: Feature Correlation Pearson Correlation Coefficients
    :target: api/target/feature_correlation.html#pearson-correlation
